package com.agri.system.service.impl;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import cn.hutool.core.lang.hash.Hash;
import com.agri.common.utils.DateUtils;
import com.agri.system.domain.SysAgriLimitBak;
import com.agri.system.domain.SysDtuRemarkBak;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import com.agri.system.mapper.SysAgriLimitBakMapper;
import com.agri.system.domain.SysAgriLimitBak;
import com.agri.system.service.ISysAgriLimitBakService;

/**
 * 大棚功能执行时间限位Service业务层处理
 * 
 * @author lld
 * @date 2026-03-17
 */
@Service
public class SysAgriLimitBakServiceImpl extends ServiceImpl<SysAgriLimitBakMapper, SysAgriLimitBak> implements ISysAgriLimitBakService 
{

    /**
     * 查询大棚功能执行时间限位
     * 
     * @param id 大棚功能执行时间限位主键
     * @return 大棚功能执行时间限位
     */
    @Override
    public SysAgriLimitBak selectSysAgriLimitBakById(String id)
    {
        return baseMapper.selectSysAgriLimitBakById(id);
    }

    /**
     * 查询大棚功能执行时间限位列表
     * 
     * @param sysAgriLimitBak 大棚功能执行时间限位
     * @return 大棚功能执行时间限位
     */
    @Override
    public List<SysAgriLimitBak> selectSysAgriLimitBakList(SysAgriLimitBak sysAgriLimitBak)
    {
        return baseMapper.selectSysAgriLimitBakList(sysAgriLimitBak);
    }

    /**
     * 新增大棚功能执行时间限位
     * 
     * @param sysAgriLimitBak 大棚功能执行时间限位
     * @return 结果
     */
    @Override
    public int insertSysAgriLimitBak(SysAgriLimitBak sysAgriLimitBak)
    {
        sysAgriLimitBak.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertSysAgriLimitBak(sysAgriLimitBak);
    }

    /**
     * 修改大棚功能执行时间限位
     * 
     * @param sysAgriLimitBak 大棚功能执行时间限位
     * @return 结果
     */
    @Override
    public int updateSysAgriLimitBak(SysAgriLimitBak sysAgriLimitBak)
    {
        sysAgriLimitBak.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateSysAgriLimitBak(sysAgriLimitBak);
    }

    /**
     * 批量删除大棚功能执行时间限位
     * 
     * @param ids 需要删除的大棚功能执行时间限位主键
     * @return 结果
     */
    @Override
    public int deleteSysAgriLimitBakByIds(String[] ids)
    {
        return baseMapper.deleteSysAgriLimitBakByIds(ids);
    }

    /**
     * 删除大棚功能执行时间限位信息
     * 
     * @param id 大棚功能执行时间限位主键
     * @return 结果
     */
    @Override
    public int deleteSysAgriLimitBakById(String id)
    {
        return baseMapper.deleteSysAgriLimitBakById(id);
    }



    @Override
    public SysAgriLimitBak getAgriLimitByImei(String imei) {

        SysAgriLimitBak agriLimit = new SysAgriLimitBak();
        if (StringUtils.isEmpty(imei)) return agriLimit;
        List<SysAgriLimitBak> limitList = super.lambdaQuery()
                .select(
                        SysAgriLimitBak::getImei,
                        SysAgriLimitBak::getRoller,
                        SysAgriLimitBak::getFuncLimit
                )
                .eq(SysAgriLimitBak::getImei, imei)
                .list();
        if (CollectionUtils.isEmpty(limitList)) return agriLimit;
        SysAgriLimitBak agriLimitBak = limitList.get(0);
        agriLimit.setImei(agriLimitBak.getImei());
        agriLimit.setAgriId(agriLimitBak.getAgriId());
        agriLimit.setAgriName(agriLimitBak.getAgriName());
        HashMap<String, BigDecimal> map = new HashMap<>();
        for (SysAgriLimitBak dtuRemark : limitList) {
            map.put(dtuRemark.getRoller(), dtuRemark.getFuncLimit());
        }
        agriLimit.setLimitMaps(map);
        return agriLimit;
    }

    @Override
    public boolean saveAgriLimit(SysAgriLimitBak sysAgriLimitBak) {

        Map<String, Object> map = new HashMap<>();
        map.put("imei", sysAgriLimitBak.getImei());
        map.put("roller",sysAgriLimitBak.getRoller());
        boolean remove = super.removeByMap(map);
        return super.save(sysAgriLimitBak);
    }
}
